@@ -1625,6 +1625,31 @@ svgStyleCSS <- function(svgstyle) {
   }
 }
 
+# SVG version of gpar()
+assign("SVGParList",
+       # http://www.w3.org/TR/SVG11/shapes.html#RectElement
+       c(# graphical event attributes
+         'onfocusin', 'onfocusout', 'onactivate', 'onclick', 'onmousedown',
+         'onmouseup', 'onmouseover', 'onmousemove', 'onmouseout', 'onload',
+         # presentation attributes
+         'alignment-baseline', 'baseline-shift', 'clip', 'clip-path',
+         'clip-rule', 'color', 'color-interpolation',
+         'color-interpolation-filters', 'color-profile', 'color-rendering',
+         'cursor', 'direction', 'display', 'dominant-baseline',
+         'enable-background', 'fill', 'fill-opacity', 'fill-rule',
+         'filter', 'flood-color', 'flood-opacity', 'font-family', 'font-size',
+         'font-size-adjust', 'font-stretch', 'font-style', 'font-variant',
+         'font-weight', 'glyph-orientation-horizontal',
+         'glyph-orientation-vertical', 'image-rendering', 'kerning',
+         'letter-spacing', 'lighting-color', 'marker-end', 'marker-mid',
+         'marker-start', 'mask', 'opacity', 'overflow', 'pointer-events',
+         'shape-rendering', 'stop-color', 'stop-opacity', 'stroke',
+         'stroke-dasharray', 'stroke-dashoffset', 'stroke-linecap',
+         'stroke-linejoin', 'stroke-miterlimit', 'stroke-opacity',
+         'stroke-width', 'text-anchor', 'text-decoration', 'text-rendering',
+         'unicode-bidi', 'visibility', 'word-spacing', 'writing-mode'),
+       envir=.gridSVGEnv)
+
 # NOTE using SVG presentation attributes
 # RATHER THAN CSS style attribute
 # BECAUSE ...
@@ -1640,6 +1665,11 @@ svgStyleAttributes <- function(svgstyle) {
     } else {
         if (any(sapply(svgstyle, length) > 1))
             stop("All SVG style attribute values must have length 1")
+        names <- names(svgstyle)
+        svgnames <- names %in% get("SVGParList", envir=.gridSVGEnv)
+        if (any(!svgnames))
+            warning(paste("Non-SVG style attribute name(s):",
+                          paste(names[!svgnames], collapse=", ")))
         svgstyle
     }
 }
